#
# spec file for package python-django-pyscss
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-django-pyscss
Version:        2.0.2
Release:        lp152.3.2
Summary:        A collection of tools to use pyScss within Django
License:        BSD-2-Clause
Group:          Development/Languages/Python
URL:            https://github.com/fusionbox/django-pyscss
Source:         https://files.pythonhosted.org/packages/source/d/django-pyscss/django-pyscss-%{version}.tar.gz
Patch0:         no-discover-runner.patch
Patch1:         django10.patch
Patch2:         fix-testproject-settings.py.patch
Patch3:         django-1.10-urls.patterns-removed.patch
Patch4:         FTBFS-fix-unit-tests.patch
Patch5:         django-2.0.patch
Patch6:         crashing_templates.patch
BuildRequires:  %{python_module Django >= 1.10}
BuildRequires:  %{python_module Pillow}
BuildRequires:  %{python_module django-compressor >= 1.3}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module pyScss >= 1.2.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python2-pathlib
Requires:       python-Django >= 1.10
Requires:       python-pyScss >= 1.3.4
Requires:       python2-pathlib
%python_subpackages

%description
This app smooths over a lot of things when dealing with pyScss in Django. It

- Overwrites the import system to use Django's staticfiles app. This way, one
  can import SCSS files from any app (or any file that's findable by the
  STATICFILES_FINDERS).

- Configures pyScss to work with the staticfiles app for its image functions
  (e.g. inline-image and sprite-map).

- It provides a django-compressor precompile filter class so that the developer
  can use pyScss with django-compressor without having to bust out to the
  shell.  This has the added benefit of removing the need to configure pyScss
  through its command-line arguments, AND makes it possible for the exceptions
  and warnings that pyScss emits to bubble up to the process so that the user
  actually knows what's going on.

%prep
%setup -q -n django-pyscss-%{version}
%autopatch -p1

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

# %%check
# Tests crash python interpreter gh#Kronuz/pyScss#378
# %%python_exec setup.py test -v

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/django_pyscss
%{python_sitelib}/django_pyscss-%{version}-py*.egg-info

%{python_sitelib}/*

%changelog
* Mon Feb  3 2020 pgajdos@suse.com
- require django-compressor instead of django_compressor
* Sat Jan 19 2019 Thomas Bechtold <tbechtold@suse.com>
- Now really disable the tests (as they crash the interpreter)
* Fri Jan 18 2019 mcepl@suse.com
- Identify crash and its ticket upstream
- Add crashing_templates.patch to avoid some problems when
  testing.
* Thu Jan 17 2019 Jan Engelhardt <jengelh@inai.de>
- Generalize description.
* Thu Jan 17 2019 Tomáš Chvátal <tchvatal@suse.com>
- Disable the tests as they crash interpreter
* Thu Jan  3 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch no-discover-runner.patch as it is no longer separate
  package but core part of django
- Enable tests and add missing dependencies
- Add patch to work with django 1.10:
  * django10.patch
- Add patches for tests from debian:
  * FTBFS-fix-unit-tests.patch
  * django-1.10-urls.patterns-removed.patch
  * fix-testproject-settings.py.patch
- Add patch to work with url syntax of django 2.0:
  * django-2.0.patch
* Wed Jan  2 2019 Thomas Bechtold <tbechtold@suse.com>
- convert to singlespec
* Mon May  4 2015 dmueller@suse.com
- update to 2.0.2:
  - Fixed bug with relative imports
  - Explicitly depend on pathlib, instead of assuming pyScss will require it.
  - Fixed cases where DEBUG is False but collectstatic hasn't been run (common in tests).
  - Added support for pyScss 1.3 and Python 3.
  - Dropped support for pyScss 1.2
- adjust requires
* Tue Oct 21 2014 dmueller@suse.com
- add buildrequires for requires
* Fri Oct 10 2014 dmueller@suse.com
- fix license/package license/README
* Thu Sep 18 2014 dmueller@suse.com
- update to 1.0.3:
  * The function ``find_all_files`` ignored ``storage.prefix``
  when looking for files, which made it fail when a prefix
  was used in ``STATICFILES_DIRS``.
* Fri Sep 12 2014 dmueller@suse.com
- Initial package
